==> zzyj-laborservice-impl-3.0.0-20250424.002805-88-sources.jar: com/ejianc/business/bid/bean/BidEnrollEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 劳务公司-投标报名
 * 
 * @author generator
 * 
 */
 @TableName("zzyj_laborservice_bid_enroll")
public class BidEnrollEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="project_id")
    private String projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="service_date")
    private Date serviceDate; // 业务日期
    @TableField(value="true_project_name")
    private String trueProjectName; // 实际项目名称
    @TableField(value="bid_org_id")
    private Long bidOrgId; // 投标单位
    @TableField(value="bid_org_name")
    private String bidOrgName; // 投标单位名称
    @TableField(value="follow_person")
    private Long followPerson; // 单位负责人
    @TableField(value="follow_person_name")
    private String followPersonName; // 负责人名称
    @TableField(value="follow_person_phone")
    private String followPersonPhone; // 负责人电话
    @TableField(value="inner_person")
    private Long innerPerson; // 内部业务员
    @TableField(value="inner_person_name")
    private String innerPersonName; // 内部业务员名称
    @TableField(value="enroll_date")
    private Date enrollDate; // 投标日期
    @TableField(value="plan_enroll_date")
    private Date planEnrollDate; // 预计启动（招标）日期
    @TableField(value="info_source")
    private Long infoSource; // 信息来源
    @TableField(value="plan_mny")
    private BigDecimal planMny; // 预计承揽金额
    @TableField(value="plan_mode")
    private String planMode; // 预计项目总规模
    @TableField(value="area")
    private String area; // 地区
    @TableField(value="address")
    private String address; // 工程地点
    @TableField(value="province")
    private String province; // 省份
    @TableField(value="city")
    private String city; // 市
    @TableField(value="region")
    private String region; // 区县
    @TableField(value="adcode")
    private String adcode; // 区划编码
    @TableField(value="first_party")
    private Long firstParty; // 甲方
    @TableField(value="first_party_name")
    private String firstPartyName; // 甲方名称
    @TableField(value="first_party_type")
    private String firstPartyType; // 甲方单位性质
    @TableField(value="bidding_org")
    private Long biddingOrg; // 招标单位
    @TableField(value="bidding_org_name")
    private String biddingOrgName; // 招标单位名称
    @TableField(value="bidding_person")
    private Long biddingPerson; // 招标单位负责人
    @TableField(value="bidding_person_name")
    private String biddingPersonName; // 招标单位负责人名称
    @TableField(value="bidding_person_phone")
    private String biddingPersonPhone; // 招标负责人电话
    @TableField(value="bidding_org_type")
    private String biddingOrgType; // 招标单位性质
    @TableField(value="bidding_agent")
    private String biddingAgent; // 招标中介(招标代理机构)
    @TableField(value="bid_follow_type")
    private String bidFollowType; // 跟踪状态
    @TableField(value="bid_state")
    private String bidState; // 报名状态
    @TableField(value="follow_remark")
    private String followRemark; // 跟踪进展
    @TableField(value="follow_date")
    private Date followDate; // 跟踪日期
    @TableField(value="bid_type")
    private String bidType; // 投标形式
    @TableField(value="info_source_name")
    private String infoSourceName; // 信息来源名称
    @TableField(value="project_remark")
    private String projectRemark; // 项目概况
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getServiceDate() {
        return serviceDate;
    }

    public void setServiceDate(Date serviceDate) {
        this.serviceDate = serviceDate;
    }
    public String getTrueProjectName() {
        return trueProjectName;
    }

    public void setTrueProjectName(String trueProjectName) {
        this.trueProjectName = trueProjectName;
    }
    public Long getBidOrgId() {
        return bidOrgId;
    }

    public void setBidOrgId(Long bidOrgId) {
        this.bidOrgId = bidOrgId;
    }
    public String getBidOrgName() {
        return bidOrgName;
    }

    public void setBidOrgName(String bidOrgName) {
        this.bidOrgName = bidOrgName;
    }
    public Long getFollowPerson() {
        return followPerson;
    }

    public void setFollowPerson(Long followPerson) {
        this.followPerson = followPerson;
    }
    public String getFollowPersonName() {
        return followPersonName;
    }

    public void setFollowPersonName(String followPersonName) {
        this.followPersonName = followPersonName;
    }
    public String getFollowPersonPhone() {
        return followPersonPhone;
    }

    public void setFollowPersonPhone(String followPersonPhone) {
        this.followPersonPhone = followPersonPhone;
    }
    public Long getInnerPerson() {
        return innerPerson;
    }

    public void setInnerPerson(Long innerPerson) {
        this.innerPerson = innerPerson;
    }
    public String getInnerPersonName() {
        return innerPersonName;
    }

    public void setInnerPersonName(String innerPersonName) {
        this.innerPersonName = innerPersonName;
    }
    public Date getEnrollDate() {
        return enrollDate;
    }

    public void setEnrollDate(Date enrollDate) {
        this.enrollDate = enrollDate;
    }
    public Date getPlanEnrollDate() {
        return planEnrollDate;
    }

    public void setPlanEnrollDate(Date planEnrollDate) {
        this.planEnrollDate = planEnrollDate;
    }
    public Long getInfoSource() {
        return infoSource;
    }

    public void setInfoSource(Long infoSource) {
        this.infoSource = infoSource;
    }
    public BigDecimal getPlanMny() {
        return planMny;
    }

    public void setPlanMny(BigDecimal planMny) {
        this.planMny = planMny;
    }
    public String getPlanMode() {
        return planMode;
    }

    public void setPlanMode(String planMode) {
        this.planMode = planMode;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }
    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }
    public String getRegion() {
        return region;
    }

    public void setRegion(String region) {
        this.region = region;
    }
    public String getAdcode() {
        return adcode;
    }

    public void setAdcode(String adcode) {
        this.adcode = adcode;
    }
    public Long getFirstParty() {
        return firstParty;
    }

    public void setFirstParty(Long firstParty) {
        this.firstParty = firstParty;
    }
    public String getFirstPartyName() {
        return firstPartyName;
    }

    public void setFirstPartyName(String firstPartyName) {
        this.firstPartyName = firstPartyName;
    }
    public String getFirstPartyType() {
        return firstPartyType;
    }

    public void setFirstPartyType(String firstPartyType) {
        this.firstPartyType = firstPartyType;
    }
    public Long getBiddingOrg() {
        return biddingOrg;
    }

    public void setBiddingOrg(Long biddingOrg) {
        this.biddingOrg = biddingOrg;
    }
    public String getBiddingOrgName() {
        return biddingOrgName;
    }

    public void setBiddingOrgName(String biddingOrgName) {
        this.biddingOrgName = biddingOrgName;
    }
    public Long getBiddingPerson() {
        return biddingPerson;
    }

    public void setBiddingPerson(Long biddingPerson) {
        this.biddingPerson = biddingPerson;
    }
    public String getBiddingPersonName() {
        return biddingPersonName;
    }

    public void setBiddingPersonName(String biddingPersonName) {
        this.biddingPersonName = biddingPersonName;
    }
    public String getBiddingPersonPhone() {
        return biddingPersonPhone;
    }

    public void setBiddingPersonPhone(String biddingPersonPhone) {
        this.biddingPersonPhone = biddingPersonPhone;
    }
    public String getBiddingOrgType() {
        return biddingOrgType;
    }

    public void setBiddingOrgType(String biddingOrgType) {
        this.biddingOrgType = biddingOrgType;
    }
    public String getBiddingAgent() {
        return biddingAgent;
    }

    public void setBiddingAgent(String biddingAgent) {
        this.biddingAgent = biddingAgent;
    }
    public String getBidFollowType() {
        return bidFollowType;
    }

    public void setBidFollowType(String bidFollowType) {
        this.bidFollowType = bidFollowType;
    }
    public String getBidState() {
        return bidState;
    }

    public void setBidState(String bidState) {
        this.bidState = bidState;
    }
    public String getFollowRemark() {
        return followRemark;
    }

    public void setFollowRemark(String followRemark) {
        this.followRemark = followRemark;
    }
    public Date getFollowDate() {
        return followDate;
    }

    public void setFollowDate(Date followDate) {
        this.followDate = followDate;
    }
    public String getBidType() {
        return bidType;
    }

    public void setBidType(String bidType) {
        this.bidType = bidType;
    }
    public String getInfoSourceName() {
        return infoSourceName;
    }

    public void setInfoSourceName(String infoSourceName) {
        this.infoSourceName = infoSourceName;
    }
    public String getProjectRemark() {
        return projectRemark;
    }

    public void setProjectRemark(String projectRemark) {
        this.projectRemark = projectRemark;
    }
    
}

==> zzyj-laborservice-impl-3.0.0-20251110.093158-99-sources.jar: com/ejianc/business/bid/bean/BidEnrollEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 劳务公司-投标报名
 * 
 * @author generator
 * 
 */
 @TableName("zzyj_laborservice_bid_enroll")
public class BidEnrollEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="project_id")
    private String projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="service_date")
    private Date serviceDate; // 业务日期
    @TableField(value="true_project_name")
    private String trueProjectName; // 实际项目名称
    @TableField(value="bid_org_id")
    private Long bidOrgId; // 投标单位
    @TableField(value="bid_org_name")
    private String bidOrgName; // 投标单位名称
    @TableField(value="follow_person")
    private Long followPerson; // 单位负责人
    @TableField(value="follow_person_name")
    private String followPersonName; // 负责人名称
    @TableField(value="follow_person_phone")
    private String followPersonPhone; // 负责人电话
    @TableField(value="inner_person")
    private Long innerPerson; // 内部业务员
    @TableField(value="inner_person_name")
    private String innerPersonName; // 内部业务员名称
    @TableField(value="enroll_date")
    private Date enrollDate; // 投标日期
    @TableField(value="plan_enroll_date")
    private Date planEnrollDate; // 预计启动（招标）日期
    @TableField(value="info_source")
    private Long infoSource; // 信息来源
    @TableField(value="plan_mny")
    private BigDecimal planMny; // 预计承揽金额
    @TableField(value="plan_mode")
    private String planMode; // 预计项目总规模
    @TableField(value="area")
    private String area; // 地区
    @TableField(value="address")
    private String address; // 工程地点
    @TableField(value="province")
    private String province; // 省份
    @TableField(value="city")
    private String city; // 市
    @TableField(value="region")
    private String region; // 区县
    @TableField(value="adcode")
    private String adcode; // 区划编码
    @TableField(value="first_party")
    private Long firstParty; // 甲方
    @TableField(value="first_party_name")
    private String firstPartyName; // 甲方名称
    @TableField(value="first_party_type")
    private String firstPartyType; // 甲方单位性质
    @TableField(value="bidding_org")
    private Long biddingOrg; // 招标单位
    @TableField(value="bidding_org_name")
    private String biddingOrgName; // 招标单位名称
    @TableField(value="bidding_person")
    private Long biddingPerson; // 招标单位负责人
    @TableField(value="bidding_person_name")
    private String biddingPersonName; // 招标单位负责人名称
    @TableField(value="bidding_person_phone")
    private String biddingPersonPhone; // 招标负责人电话
    @TableField(value="bidding_org_type")
    private String biddingOrgType; // 招标单位性质
    @TableField(value="bidding_agent")
    private String biddingAgent; // 招标中介(招标代理机构)
    @TableField(value="bid_follow_type")
    private String bidFollowType; // 跟踪状态
    @TableField(value="bid_state")
    private String bidState; // 报名状态
    @TableField(value="follow_remark")
    private String followRemark; // 跟踪进展
    @TableField(value="follow_date")
    private Date followDate; // 跟踪日期
    @TableField(value="bid_type")
    private String bidType; // 投标形式
    @TableField(value="info_source_name")
    private String infoSourceName; // 信息来源名称
    @TableField(value="project_remark")
    private String projectRemark; // 项目概况
    @TableField(value="apply_area")
    private String applyArea;//地区
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getServiceDate() {
        return serviceDate;
    }

    public void setServiceDate(Date serviceDate) {
        this.serviceDate = serviceDate;
    }
    public String getTrueProjectName() {
        return trueProjectName;
    }

    public void setTrueProjectName(String trueProjectName) {
        this.trueProjectName = trueProjectName;
    }
    public Long getBidOrgId() {
        return bidOrgId;
    }

    public void setBidOrgId(Long bidOrgId) {
        this.bidOrgId = bidOrgId;
    }
    public String getBidOrgName() {
        return bidOrgName;
    }

    public void setBidOrgName(String bidOrgName) {
        this.bidOrgName = bidOrgName;
    }
    public Long getFollowPerson() {
        return followPerson;
    }

    public void setFollowPerson(Long followPerson) {
        this.followPerson = followPerson;
    }
    public String getFollowPersonName() {
        return followPersonName;
    }

    public void setFollowPersonName(String followPersonName) {
        this.followPersonName = followPersonName;
    }
    public String getFollowPersonPhone() {
        return followPersonPhone;
    }

    public void setFollowPersonPhone(String followPersonPhone) {
        this.followPersonPhone = followPersonPhone;
    }
    public Long getInnerPerson() {
        return innerPerson;
    }

    public void setInnerPerson(Long innerPerson) {
        this.innerPerson = innerPerson;
    }
    public String getInnerPersonName() {
        return innerPersonName;
    }

    public void setInnerPersonName(String innerPersonName) {
        this.innerPersonName = innerPersonName;
    }
    public Date getEnrollDate() {
        return enrollDate;
    }

    public void setEnrollDate(Date enrollDate) {
        this.enrollDate = enrollDate;
    }
    public Date getPlanEnrollDate() {
        return planEnrollDate;
    }

    public void setPlanEnrollDate(Date planEnrollDate) {
        this.planEnrollDate = planEnrollDate;
    }
    public Long getInfoSource() {
        return infoSource;
    }

    public void setInfoSource(Long infoSource) {
        this.infoSource = infoSource;
    }
    public BigDecimal getPlanMny() {
        return planMny;
    }

    public void setPlanMny(BigDecimal planMny) {
        this.planMny = planMny;
    }
    public String getPlanMode() {
        return planMode;
    }

    public void setPlanMode(String planMode) {
        this.planMode = planMode;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }
    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }
    public String getRegion() {
        return region;
    }

    public void setRegion(String region) {
        this.region = region;
    }
    public String getAdcode() {
        return adcode;
    }

    public void setAdcode(String adcode) {
        this.adcode = adcode;
    }
    public Long getFirstParty() {
        return firstParty;
    }

    public void setFirstParty(Long firstParty) {
        this.firstParty = firstParty;
    }
    public String getFirstPartyName() {
        return firstPartyName;
    }

    public void setFirstPartyName(String firstPartyName) {
        this.firstPartyName = firstPartyName;
    }
    public String getFirstPartyType() {
        return firstPartyType;
    }

    public void setFirstPartyType(String firstPartyType) {
        this.firstPartyType = firstPartyType;
    }
    public Long getBiddingOrg() {
        return biddingOrg;
    }

    public void setBiddingOrg(Long biddingOrg) {
        this.biddingOrg = biddingOrg;
    }
    public String getBiddingOrgName() {
        return biddingOrgName;
    }

    public void setBiddingOrgName(String biddingOrgName) {
        this.biddingOrgName = biddingOrgName;
    }
    public Long getBiddingPerson() {
        return biddingPerson;
    }

    public void setBiddingPerson(Long biddingPerson) {
        this.biddingPerson = biddingPerson;
    }
    public String getBiddingPersonName() {
        return biddingPersonName;
    }

    public void setBiddingPersonName(String biddingPersonName) {
        this.biddingPersonName = biddingPersonName;
    }
    public String getBiddingPersonPhone() {
        return biddingPersonPhone;
    }

    public void setBiddingPersonPhone(String biddingPersonPhone) {
        this.biddingPersonPhone = biddingPersonPhone;
    }
    public String getBiddingOrgType() {
        return biddingOrgType;
    }

    public void setBiddingOrgType(String biddingOrgType) {
        this.biddingOrgType = biddingOrgType;
    }
    public String getBiddingAgent() {
        return biddingAgent;
    }

    public void setBiddingAgent(String biddingAgent) {
        this.biddingAgent = biddingAgent;
    }
    public String getBidFollowType() {
        return bidFollowType;
    }

    public void setBidFollowType(String bidFollowType) {
        this.bidFollowType = bidFollowType;
    }
    public String getBidState() {
        return bidState;
    }

    public void setBidState(String bidState) {
        this.bidState = bidState;
    }
    public String getFollowRemark() {
        return followRemark;
    }

    public void setFollowRemark(String followRemark) {
        this.followRemark = followRemark;
    }
    public Date getFollowDate() {
        return followDate;
    }

    public void setFollowDate(Date followDate) {
        this.followDate = followDate;
    }
    public String getBidType() {
        return bidType;
    }

    public void setBidType(String bidType) {
        this.bidType = bidType;
    }
    public String getInfoSourceName() {
        return infoSourceName;
    }

    public void setInfoSourceName(String infoSourceName) {
        this.infoSourceName = infoSourceName;
    }
    public String getProjectRemark() {
        return projectRemark;
    }

    public void setProjectRemark(String projectRemark) {
        this.projectRemark = projectRemark;
    }

    public String getApplyArea() {
        return applyArea;
    }

    public void setApplyArea(String applyArea) {
        this.applyArea = applyArea;
    }
}
